@@ -1,4 +1,4 @@
-// Copyright 2013-2024 Daniel Parker
+// Copyright 2013-2025 Daniel Parker
 // Distributed under the Boost license, Version 1.0.
 // (See accompanying file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
 
@@ -8,13 +8,22 @@
 #define JSONCONS_CONFIG_COMPILER_SUPPORT_HPP
 
 #include <cmath>
-#include <exception>
-#include <ostream>
-#include <stdexcept>
-#include <string>
+#include <cstdint>
 #include <cstring> // std::memcpy
 #include <limits> // std::numeric_limits
 
+#if !defined(JSONCONS_NO_EXCEPTIONS)
+    #define JSONCONS_THROW(exception) throw exception
+    #define JSONCONS_RETHROW throw
+    #define JSONCONS_TRY try
+    #define JSONCONS_CATCH(exception) catch(exception)
+#else
+    #define JSONCONS_THROW(exception) std::terminate()
+    #define JSONCONS_RETHROW std::terminate()
+    #define JSONCONS_TRY if (true)
+    #define JSONCONS_CATCH(exception) if (false)
+#endif
+
 #if defined(__GNUC__)
 #   if defined(__GNUC_PATCHLEVEL__)
 #       define JSONCONS_GCC_AVAILABLE(major, minor, patch) \
@@ -238,19 +247,6 @@
 #endif
 #endif
 
-// allow to disable exceptions
-#if !defined(JSONCONS_NO_EXCEPTIONS)
-    #define JSONCONS_THROW(exception) throw exception
-    #define JSONCONS_RETHROW throw
-    #define JSONCONS_TRY try
-    #define JSONCONS_CATCH(exception) catch(exception)
-#else
-    #define JSONCONS_THROW(exception) std::terminate()
-    #define JSONCONS_RETHROW std::terminate()
-    #define JSONCONS_TRY if (true)
-    #define JSONCONS_CATCH(exception) if (false)
-#endif
-
 #if !defined(JSONCONS_HAS_STD_MAKE_UNIQUE)
    #if defined(__clang__) && defined(__cplusplus)
       #if defined(__APPLE__)
@@ -489,5 +485,6 @@ namespace binary {
 
 } // namespace binary
 } // namespace jsoncons
+// allow to disable exceptions
 
 #endif // JSONCONS_CONFIG_COMPILER_SUPPORT_HPP
