@@ -1,4 +1,4 @@
-// Copyright 2013-2024 Daniel Parker
+// Copyright 2013-2025 Daniel Parker
 // Distributed under the Boost license, Version 1.0.
 // (See accompanying file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
 
@@ -8,10 +8,15 @@
 #define JSONCONS_UTILITY_URI_HPP
 
 #include <algorithm> 
+#include <cstddef>
+#include <cstdint>
 #include <iostream>
-#include <sstream> 
 #include <string> // std::string
+#include <system_error>
+#include <type_traits>
+#include <utility>
 
+#include <jsoncons/config/compiler_support.hpp>
 #include <jsoncons/config/jsoncons_config.hpp>
 #include <jsoncons/detail/parse_number.hpp>
 #include <jsoncons/detail/write_number.hpp>
