@@ -1,4 +1,4 @@
-// Copyright 2013-2024 Daniel Parker
+// Copyright 2013-2025 Daniel Parker
 // Distributed under the Boost license, Version 1.0.
 // (See accompanying file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)
 
@@ -8,14 +8,17 @@
 #define JSONCONS_EXT_UBJSON_DECODE_UBJSON_HPP
 
 #include <istream> // std::basic_istream
-#include <memory>
-#include <string>
 #include <type_traits> // std::enable_if
-#include <vector>
 
 #include <jsoncons/allocator_set.hpp>
+#include <jsoncons/config/compiler_support.hpp>
 #include <jsoncons/config/jsoncons_config.hpp>
-#include <jsoncons/json.hpp>
+#include <jsoncons/basic_json.hpp>
+#include <jsoncons/conv_error.hpp>
+#include <jsoncons/decode_traits.hpp>
+#include <jsoncons/json_decoder.hpp>
+#include <jsoncons/source.hpp>
+
 #include <jsoncons_ext/ubjson/ubjson_cursor.hpp>
 #include <jsoncons_ext/ubjson/ubjson_reader.hpp>
 
