@@ -1,4 +1,4 @@
-// Copyright 2013-2024 Daniel Parker
+// Copyright 2013-2025 Daniel Parker
 // Distributed under Boost license
 
 #if defined(_MSC_VER)
@@ -18,7 +18,7 @@ using namespace jsoncons;
 namespace {
 namespace ns {
 
-    template <typename T1, typename T2>
+    template <typename T1,typename T2>
     struct TemplatedStruct
     {
           T1 aT1;
@@ -497,7 +497,7 @@ void test_is_json_type_traits_declared(std::true_type)
 
 namespace 
 {
-    template <class T>
+    template <typename T>
     struct MyAlloc
     {
         using value_type = T;
@@ -509,7 +509,7 @@ namespace
         #endif
         MyAlloc(int) {}
 
-        template< class U >
+        template< typename U >
         MyAlloc(const MyAlloc<U>&) noexcept {}
 
         T* allocate(size_type n)
@@ -525,7 +525,7 @@ namespace
         bool operator==(const MyAlloc&) const { return true; }
         bool operator!=(const MyAlloc&) const { return false; }
 
-        template<typename U>
+        template <typename U>
         struct rebind
         {
             using other = MyAlloc<U>;
@@ -1161,7 +1161,7 @@ TEST_CASE("hiking_reputation")
     SECTION("3")
     {
         std::string s;
-        json_options options;
+        auto options = json_options{};
         encode_json(val, s, options, indenting::indent);
         auto val2 = decode_json<ns::hiking_reputation>(s, options);
         CHECK(val2 == val);
@@ -1187,7 +1187,7 @@ TEST_CASE("hiking_reputation")
     SECTION("6")
     {
         std::string s;
-        json_options options;
+        auto options = json_options{};
         encode_json(val, s, options, indenting::indent);
         auto val2 = decode_json<ns::hiking_reputation>(temp_allocator_only(alloc1),
                                                        s, options);
@@ -1213,7 +1213,7 @@ TEST_CASE("hiking_reputation")
     SECTION("os 3")
     {
         std::stringstream os;
-        json_options options;
+        auto options = json_options{};
         encode_json_pretty(val, os);
         auto val2 = decode_json<ns::hiking_reputation>(os, options);
         CHECK(val2 == val);
@@ -1240,7 +1240,7 @@ TEST_CASE("hiking_reputation")
     SECTION("os 6")
     {
         std::stringstream os;
-        json_options options;
+        auto options = json_options{};
         encode_json_pretty(val, os, options);
         auto val2 = decode_json<ns::hiking_reputation>(temp_allocator_only(alloc1),
                                                        os, options);
